==> IO-K8s-1.000.tar.gz: IO-K8s-1.000/lib/IO/K8s/Api/Networking/V1/IngressBackend.pm <==
package IO::K8s::Api::Networking::V1::IngressBackend;
# ABSTRACT: IngressBackend describes all endpoints for a given service and port.
our $VERSION = '1.000';
use IO::K8s::Resource;

k8s resource => 'Core::V1::TypedLocalObjectReference';


k8s service => 'Networking::V1::IngressServiceBackend';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Networking::V1::IngressBackend - IngressBackend describes all endpoints for a given service and port.

=head1 VERSION

version 1.000

=head2 resource

resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, a service.Name and service.Port must not be specified. This is a mutually exclusive setting with "Service".

=head2 service

service references a service as a backend. This is a mutually exclusive setting with "Resource".

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartinez@capside.com> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by CAPSiDE.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

==> IO-K8s-1.001.tar.gz: IO-K8s-1.001/lib/IO/K8s/Api/Networking/V1/IngressBackend.pm <==
package IO::K8s::Api::Networking::V1::IngressBackend;
# ABSTRACT: IngressBackend describes all endpoints for a given service and port.
our $VERSION = '1.001';
use IO::K8s::Resource;

k8s resource => 'Core::V1::TypedLocalObjectReference';


k8s service => 'Networking::V1::IngressServiceBackend';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Networking::V1::IngressBackend - IngressBackend describes all endpoints for a given service and port.

=head1 VERSION

version 1.001

=head2 resource

resource is an ObjectRef to another Kubernetes resource in the namespace of the Ingress object. If resource is specified, a service.Name and service.Port must not be specified. This is a mutually exclusive setting with "Service".

=head2 service

service references a service as a backend. This is a mutually exclusive setting with "Resource".

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
